@@ -31,7 +31,7 @@
 #ifdef HAVE_CAIRO_PS
 #include <cairo-ps.h>
 #endif
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 #include "ev-poppler.h"
 #include "ev-file-exporter.h"
@@ -45,6 +45,8 @@
 #include "ev-document-transition.h"
 #include "ev-document-forms.h"
 #include "ev-document-layers.h"
+#include "ev-document-print.h"
+#include "ev-document-annotations.h"
 #include "ev-selection.h"
 #include "ev-transition-effect.h"
 #include "ev-attachment.h"
@@ -92,6 +94,7 @@ struct _PdfDocument
 
 	PopplerDocument *document;
 	gchar *password;
+	gboolean modified;
 
 	PopplerFontInfo *font_info;
 	PopplerFontsIter *fonts_iter;
@@ -103,23 +106,27 @@ struct _PdfDocument
 	GList *layers;
 };
 
-static void pdf_document_document_iface_init            (EvDocumentIface           *iface);
-static void pdf_document_security_iface_init            (EvDocumentSecurityIface   *iface);
-static void pdf_document_document_thumbnails_iface_init (EvDocumentThumbnailsIface *iface);
-static void pdf_document_document_links_iface_init      (EvDocumentLinksIface      *iface);
-static void pdf_document_document_images_iface_init     (EvDocumentImagesIface     *iface);
-static void pdf_document_document_forms_iface_init      (EvDocumentFormsIface      *iface);
-static void pdf_document_document_fonts_iface_init      (EvDocumentFontsIface      *iface);
-static void pdf_document_document_layers_iface_init     (EvDocumentLayersIface     *iface);
-static void pdf_document_find_iface_init                (EvDocumentFindIface       *iface);
-static void pdf_document_file_exporter_iface_init       (EvFileExporterIface       *iface);
-static void pdf_selection_iface_init                    (EvSelectionIface          *iface);
-static void pdf_document_page_transition_iface_init     (EvDocumentTransitionIface *iface);
-static void pdf_document_thumbnails_get_dimensions      (EvDocumentThumbnails      *document_thumbnails,
-							 EvRenderContext           *rc,
-							 gint                      *width,
-							 gint                      *height);
-static int  pdf_document_get_n_pages			(EvDocument                *document);
+static void pdf_document_document_iface_init             (EvDocumentIface            *iface);
+static void pdf_document_security_iface_init             (EvDocumentSecurityIface    *iface);
+static void pdf_document_document_thumbnails_iface_init  (EvDocumentThumbnailsIface  *iface);
+static void pdf_document_document_links_iface_init       (EvDocumentLinksIface       *iface);
+static void pdf_document_document_images_iface_init      (EvDocumentImagesIface      *iface);
+static void pdf_document_document_forms_iface_init       (EvDocumentFormsIface       *iface);
+static void pdf_document_document_fonts_iface_init       (EvDocumentFontsIface       *iface);
+static void pdf_document_document_layers_iface_init      (EvDocumentLayersIface      *iface);
+#ifdef HAVE_POPPLER_PAGE_RENDER
+static void pdf_document_document_print_iface_init       (EvDocumentPrintIface       *iface);
+#endif
+static void pdf_document_document_annotations_iface_init (EvDocumentAnnotationsIface *iface);
+static void pdf_document_find_iface_init                 (EvDocumentFindIface        *iface);
+static void pdf_document_file_exporter_iface_init        (EvFileExporterIface        *iface);
+static void pdf_selection_iface_init                     (EvSelectionIface           *iface);
+static void pdf_document_page_transition_iface_init      (EvDocumentTransitionIface  *iface);
+static void pdf_document_thumbnails_get_dimensions       (EvDocumentThumbnails       *document_thumbnails,
+							  EvRenderContext            *rc,
+							  gint                       *width,
+							  gint                       *height);
+static int  pdf_document_get_n_pages			 (EvDocument                 *document);
 
 static EvLinkDest *ev_link_dest_from_dest   (PdfDocument       *pdf_document,
 					     PopplerDest       *dest);
@@ -144,6 +151,12 @@ EV_BACKEND_REGISTER_WITH_CODE (PdfDocument, pdf_document,
 								 pdf_document_document_fonts_iface_init);
 				 EV_BACKEND_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_LAYERS,
 								 pdf_document_document_layers_iface_init);
+#ifdef HAVE_POPPLER_PAGE_RENDER
+				 EV_BACKEND_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_PRINT,
+								 pdf_document_document_print_iface_init);
+#endif
+				 EV_BACKEND_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_ANNOTATIONS,
+								 pdf_document_document_annotations_iface_init);
 				 EV_BACKEND_IMPLEMENT_INTERFACE (EV_TYPE_DOCUMENT_FIND,
 								 pdf_document_find_iface_init);
 				 EV_BACKEND_IMPLEMENT_INTERFACE (EV_TYPE_FILE_EXPORTER,
@@ -239,12 +252,12 @@ convert_error (GError  *poppler_error,
 		else if (poppler_error->code == POPPLER_ERROR_ENCRYPTED)
 			code = EV_DOCUMENT_ERROR_ENCRYPTED;
 			
+		g_set_error_literal (error,
+                                     EV_DOCUMENT_ERROR,
+                                     code,
+                                     poppler_error->message);
 
-		g_set_error (error,
-			     EV_DOCUMENT_ERROR,
-			     code,
-			     poppler_error->message,
-			     NULL);
+		g_error_free (poppler_error);
 	} else {
 		g_propagate_error (error, poppler_error);
 	}
@@ -257,12 +270,18 @@ pdf_document_save (EvDocument  *document,
 		   const char  *uri,
 		   GError     **error)
 {
+	PdfDocument *pdf_document = PDF_DOCUMENT (document);
 	gboolean retval;
 	GError *poppler_error = NULL;
 
-	retval = poppler_document_save (PDF_DOCUMENT (document)->document,
-					uri,
-					&poppler_error);
+	if (pdf_document->modified) {
+		retval = poppler_document_save (pdf_document->document,
+						uri, &poppler_error);
+	} else {
+		retval = poppler_document_save_a_copy (pdf_document->document,
+						       uri, &poppler_error);
+	}
+						       
 	if (! retval)
 		convert_error (poppler_error, error);
 
@@ -883,7 +902,7 @@ ev_link_dest_from_dest (PdfDocument *pdf_document,
 			poppler_page_get_size (poppler_page, NULL, &height);
 			ev_dest = ev_link_dest_new_xyz (dest->page_num - 1,
 							dest->left,
-							height - dest->top,
+							height - MIN (height, dest->top),
 							dest->zoom,
 							dest->change_left,
 							dest->change_top,
@@ -902,7 +921,7 @@ ev_link_dest_from_dest (PdfDocument *pdf_document,
 								  MAX (0, dest->page_num - 1));
 			poppler_page_get_size (poppler_page, NULL, &height);
 			ev_dest = ev_link_dest_new_fith (dest->page_num - 1,
-							 height - dest->top,
+							 height - MIN (height, dest->top),
 							 dest->change_top);
 			g_object_unref (poppler_page);
 		}
@@ -921,9 +940,9 @@ ev_link_dest_from_dest (PdfDocument *pdf_document,
 			poppler_page_get_size (poppler_page, NULL, &height);
 			ev_dest = ev_link_dest_new_fitr (dest->page_num - 1,
 							 dest->left,
-							 height - dest->bottom,
+							 height - MIN (height, dest->bottom),
 							 dest->right,
-							 height - dest->top);
+							 height - MIN (height, dest->top));
 			g_object_unref (poppler_page);
 		}
 			break;
@@ -1225,10 +1244,11 @@ GdkPixbuf *
 pdf_document_images_get_image (EvDocumentImages *document_images,
 			       EvImage          *image)
 {
+	GdkPixbuf       *retval = NULL;
+#ifdef HAVE_POPPLER_PAGE_GET_IMAGE
 	PdfDocument     *pdf_document;
 	PopplerPage     *poppler_page;
 	cairo_surface_t *surface;
-	GdkPixbuf       *retval = NULL;
 
 	pdf_document = PDF_DOCUMENT (document_images);
 	poppler_page = poppler_document_get_page (pdf_document->document,
@@ -1241,7 +1261,7 @@ pdf_document_images_get_image (EvDocumentImages *document_images,
 	}
 
 	g_object_unref (poppler_page);
-
+#endif
 	return retval;
 }
 
@@ -1253,15 +1273,13 @@ pdf_document_document_images_iface_init (EvDocumentImagesIface *iface)
 }
 
 static GdkPixbuf *
-make_thumbnail_for_page (PdfDocument     *pdf_document,
-			 PopplerPage     *poppler_page, 
-			 EvRenderContext *rc)
+make_thumbnail_for_page (PopplerPage     *poppler_page,
+			 EvRenderContext *rc,
+			 gint             width,
+			 gint             height)
 {
 	GdkPixbuf *pixbuf;
-	int width, height;
 
-	pdf_document_thumbnails_get_dimensions (EV_DOCUMENT_THUMBNAILS (pdf_document),
-						rc, &width, &height);
 #ifdef POPPLER_WITH_GDK
 	pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8,
 				 width, height);
@@ -1295,9 +1313,13 @@ pdf_document_thumbnails_get_thumbnail (EvDocumentThumbnails *document_thumbnails
 	PopplerPage *poppler_page;
 	GdkPixbuf *pixbuf = NULL;
 	GdkPixbuf *border_pixbuf;
+	gint width, height;
 
 	poppler_page = POPPLER_PAGE (rc->page->backend_page);
 
+	pdf_document_thumbnails_get_dimensions (EV_DOCUMENT_THUMBNAILS (pdf_document),
+						rc, &width, &height);
+	
 #ifdef POPPLER_WITH_GDK
 	pixbuf = poppler_page_get_thumbnail_pixbuf (poppler_page);
 #else
@@ -1310,20 +1332,29 @@ pdf_document_thumbnails_get_thumbnail (EvDocumentThumbnails *document_thumbnails
 	}
 #endif /* POPPLER_WITH_GDK */
 
-	if (pixbuf) {
-		/* Rotate provided thumbnail if needed */
-		GdkPixbuf *rotated_pixbuf;
+	if (pixbuf != NULL) {
+		int thumb_width = (rc->rotation == 90 || rc->rotation == 270) ?
+			gdk_pixbuf_get_height (pixbuf) :
+			gdk_pixbuf_get_width (pixbuf);
 
-		rotated_pixbuf = gdk_pixbuf_rotate_simple (pixbuf,
-							   (GdkPixbufRotation) (360 - rc->rotation));
-		g_object_unref (pixbuf);
-		pixbuf = rotated_pixbuf;
+		if (thumb_width == width) {
+			GdkPixbuf *rotated_pixbuf;
+
+			rotated_pixbuf = gdk_pixbuf_rotate_simple (pixbuf,
+								   (GdkPixbufRotation) (360 - rc->rotation));
+			g_object_unref (pixbuf);
+			pixbuf = rotated_pixbuf;
+		} else {
+			/* The provided thumbnail has a different size */
+			g_object_unref (pixbuf);
+			pixbuf = make_thumbnail_for_page (poppler_page, rc, width, height);
+		}
 	} else {
-		/* There is no provided thumbnail.  We need to make one. */
-		pixbuf = make_thumbnail_for_page (pdf_document, poppler_page, rc);
+		/* There is no provided thumbnail. We need to make one. */
+		pixbuf = make_thumbnail_for_page (poppler_page, rc, width, height);
 	}
 
-        if (border) {		
+        if (border && pixbuf) {
 		border_pixbuf = ev_document_misc_get_thumbnail_frame (-1, -1, pixbuf);
 		g_object_unref (pixbuf);
 		pixbuf = border_pixbuf;
@@ -1338,21 +1369,13 @@ pdf_document_thumbnails_get_dimensions (EvDocumentThumbnails *document_thumbnail
 					gint                 *width,
 					gint                 *height)
 {
-	PopplerPage *poppler_page;
-	gint has_thumb;
+	double page_width, page_height;
 	
-	poppler_page = POPPLER_PAGE (rc->page->backend_page);
-
-	has_thumb = poppler_page_get_thumbnail_size (poppler_page, width, height);
-
-	if (!has_thumb || *width <= 0 || *height <= 0) {
-		double page_width, page_height;
-
-		poppler_page_get_size (poppler_page, &page_width, &page_height);
-
-		*width = (gint) MAX (page_width * rc->scale, 1);
-		*height = (gint) MAX (page_height * rc->scale, 1);
-	}
+	poppler_page_get_size (POPPLER_PAGE (rc->page->backend_page),
+			       &page_width, &page_height);
+	
+	*width = (gint) MAX (page_width * rc->scale, 1);
+	*height = (gint) MAX (page_height * rc->scale, 1);
 	
 	if (rc->rotation == 90 || rc->rotation == 270) {
 		gint  temp;
@@ -1698,6 +1721,25 @@ pdf_document_file_exporter_iface_init (EvFileExporterIface *iface)
 	iface->get_capabilities = pdf_document_file_exporter_get_capabilities;
 }
 
+#ifdef HAVE_POPPLER_PAGE_RENDER
+/* EvDocumentPrint */
+static void
+pdf_document_print_print_page (EvDocumentPrint *document,
+			       EvPage          *page,
+			       cairo_t         *cr)
+{
+	PdfDocument *pdf_document = PDF_DOCUMENT (document);
+
+	poppler_page_render_for_printing (POPPLER_PAGE (page->backend_page), cr);
+}
+
+static void
+pdf_document_document_print_iface_init (EvDocumentPrintIface *iface)
+{
+	iface->print_page = pdf_document_print_print_page;
+}
+#endif /* HAVE_POPPLER_PAGE_RENDER */
+
 static void
 pdf_selection_render_selection (EvSelection      *selection,
 				EvRenderContext  *rc,
@@ -2142,7 +2184,9 @@ pdf_document_forms_form_field_text_set_text (EvDocumentForms *document,
 	poppler_field = POPPLER_FORM_FIELD (g_object_get_data (G_OBJECT (field), "poppler-field"));
 	if (!poppler_field)
 		return;
+	
 	poppler_form_field_text_set_text (poppler_field, text);
+	PDF_DOCUMENT (document)->modified = TRUE;
 }
 
 static void
@@ -2157,6 +2201,7 @@ pdf_document_forms_form_field_button_set_state (EvDocumentForms *document,
 		return;
 	
 	poppler_form_field_button_set_state (poppler_field, state);
+	PDF_DOCUMENT (document)->modified = TRUE;
 }
 
 static gboolean
@@ -2237,6 +2282,7 @@ pdf_document_forms_form_field_choice_select_item (EvDocumentForms *document,
 		return;
 
 	poppler_form_field_choice_select_item (poppler_field, index);
+	PDF_DOCUMENT (document)->modified = TRUE;
 }
 
 static void
@@ -2251,6 +2297,7 @@ pdf_document_forms_form_field_choice_toggle_item (EvDocumentForms *document,
 		return;
 
 	poppler_form_field_choice_toggle_item (poppler_field, index);
+	PDF_DOCUMENT (document)->modified = TRUE;
 }
 
 static void
@@ -2264,6 +2311,7 @@ pdf_document_forms_form_field_choice_unselect_all (EvDocumentForms *document,
 		return;
 	
 	poppler_form_field_choice_unselect_all (poppler_field);
+	PDF_DOCUMENT (document)->modified = TRUE;
 }
 
 static void
@@ -2278,6 +2326,7 @@ pdf_document_forms_form_field_choice_set_text (EvDocumentForms *document,
 		return;
 	
 	poppler_form_field_choice_set_text (poppler_field, text);
+	PDF_DOCUMENT (document)->modified = TRUE;
 }
 
 static gchar *
@@ -2314,11 +2363,189 @@ pdf_document_document_forms_iface_init (EvDocumentFormsIface *iface)
 	iface->form_field_choice_get_text = pdf_document_forms_form_field_choice_get_text;
 }
 
+/* Annotations */
+static void
+poppler_annot_color_to_gdk_color (PopplerAnnot *poppler_annot,
+				  GdkColor     *color)
+{
+	PopplerColor *poppler_color;
+
+	poppler_color = poppler_annot_get_color (poppler_annot);
+	if (poppler_color) {
+		color->red = poppler_color->red;
+		color->green = poppler_color->green;
+		color->blue = poppler_color->blue;
+
+		g_free (poppler_color);
+	} /* TODO: else use a default color */
+}
+
+static EvAnnotation *
+ev_annot_from_poppler_annot (PopplerAnnot *poppler_annot,
+			     EvPage       *page)
+{
+	EvAnnotation *ev_annot = NULL;
+	const gchar  *unimplemented_annot = NULL;
+
+	switch (poppler_annot_get_annot_type (poppler_annot)) {
+	        case POPPLER_ANNOT_TEXT:
+			PopplerAnnotText *poppler_text;
+			EvAnnotationText *ev_annot_text;
+
+			poppler_text = POPPLER_ANNOT_TEXT (poppler_annot);
+
+			ev_annot = ev_annotation_text_new (page);
+
+			ev_annot_text = EV_ANNOTATION_TEXT (ev_annot);
+			ev_annot_text->is_open = poppler_annot_text_get_is_open (poppler_text);
+
+			break;
+	        case POPPLER_ANNOT_LINK:
+	        case POPPLER_ANNOT_WIDGET:
+			/* Ignore link and widgets annots since they are already handled */
+			break;
+	        default: {
+			GEnumValue *enum_value;
+
+			enum_value = g_enum_get_value ((GEnumClass *) g_type_class_ref (POPPLER_TYPE_ANNOT_TYPE),
+						       poppler_annot_get_annot_type (poppler_annot));
+			unimplemented_annot = enum_value ? enum_value->value_name : "Unknown annotation";
+		}
+	}
+
+	if (unimplemented_annot) {
+		g_warning ("Unimplemented annotation: %s, please post a "
+		           "bug report in Evince bugzilla "
+		           "(http://bugzilla.gnome.org) with a testcase.",
+			   unimplemented_annot);
+	}
+
+	if (ev_annot) {
+		ev_annot->contents = poppler_annot_get_contents (poppler_annot);
+		ev_annot->name = poppler_annot_get_name (poppler_annot);
+		ev_annot->modified = poppler_annot_get_modified (poppler_annot);
+		poppler_annot_color_to_gdk_color (poppler_annot, &ev_annot->color);
+
+		if (POPPLER_IS_ANNOT_MARKUP (poppler_annot)) {
+			PopplerAnnotMarkup *markup;
+			gchar *label;
+			gdouble opacity;
+			gboolean is_open;
+			PopplerRectangle poppler_rect;
+
+			markup = POPPLER_ANNOT_MARKUP (poppler_annot);
+
+			if (poppler_annot_markup_get_popup_rectangle (markup, &poppler_rect)) {
+				EvRectangle ev_rect;
+				gdouble height;
+
+				poppler_page_get_size (POPPLER_PAGE (page->backend_page),
+						       NULL, &height);
+				ev_rect.x1 = poppler_rect.x1;
+				ev_rect.x2 = poppler_rect.x2;
+				ev_rect.y1 = height - poppler_rect.y2;
+				ev_rect.y2 = height - poppler_rect.y1;
+
+				g_object_set (ev_annot, "rectangle", &ev_rect, NULL);
+			}
+
+			label = poppler_annot_markup_get_label (markup);
+			opacity = poppler_annot_markup_get_opacity (markup);
+			is_open = poppler_annot_markup_get_popup_is_open (markup);
+
+			g_object_set (ev_annot,
+				      "label", label,
+				      "opacity", opacity,
+				      "is_open", is_open,
+				      NULL);
+
+			g_free (label);
+		}
+	}
+
+	return ev_annot;
+}
+
+static GList *
+pdf_document_annotations_get_annotations (EvDocumentAnnotations *document_annotations,
+					  EvPage                *page)
+{
+	GList *retval = NULL;
+	PdfDocument *pdf_document;
+	PopplerPage *poppler_page;
+	GList *annots;
+	GList *list;
+	gdouble height;
+	gint i = 0;
+
+	pdf_document = PDF_DOCUMENT (document_annotations);
+	poppler_page = POPPLER_PAGE (page->backend_page);
+	annots = poppler_page_get_annot_mapping (poppler_page);
+	poppler_page_get_size (poppler_page, NULL, &height);
+
+	for (list = annots; list; list = list->next) {
+		PopplerAnnotMapping *mapping;
+		EvAnnotationMapping *annot_mapping;
+		EvAnnotation        *ev_annot;
+
+		mapping = (PopplerAnnotMapping *)list->data;
+
+		ev_annot = ev_annot_from_poppler_annot (mapping->annot, page);
+		if (!ev_annot)
+			continue;
+
+		i++;
+
+		/* Make sure annot has a unique name */
+		if (!ev_annot->name)
+			ev_annot->name = g_strdup_printf ("annot-%d-%d", page->index, i);
+
+		annot_mapping = g_new0 (EvAnnotationMapping, 1);
+		annot_mapping->x1 = mapping->area.x1;
+		annot_mapping->x2 = mapping->area.x2;
+		annot_mapping->y1 = height - mapping->area.y2;
+		annot_mapping->y2 = height - mapping->area.y1;
+		annot_mapping->annotation = ev_annot;
+
+		g_object_set_data_full (G_OBJECT (ev_annot),
+					"poppler-annot",
+					g_object_ref (mapping->annot),
+					(GDestroyNotify) g_object_unref);
+
+		retval = g_list_prepend (retval, annot_mapping);
+	}
+
+	poppler_page_free_annot_mapping (annots);
+
+	return g_list_reverse (retval);
+}
+
+static void
+pdf_document_annotations_annotation_set_contents (EvDocumentAnnotations *document,
+						  EvAnnotation          *annot,
+						  const gchar           *contents)
+{
+	PopplerAnnot *poppler_annot;
+
+	poppler_annot = POPPLER_ANNOT (g_object_get_data (G_OBJECT (annot), "poppler-annot"));
+	if (!poppler_annot)
+		return;
+
+	poppler_annot_set_contents (poppler_annot, contents);
+	PDF_DOCUMENT (document)->modified = TRUE;
+}
+
+static void
+pdf_document_document_annotations_iface_init (EvDocumentAnnotationsIface *iface)
+{
+	iface->get_annotations = pdf_document_annotations_get_annotations;
+	iface->annotation_set_contents = pdf_document_annotations_annotation_set_contents;
+}
+
 /* Layers */
 static gboolean
 pdf_document_layers_has_layers (EvDocumentLayers *document)
 {
-#ifdef HAVE_POPPLER_LAYERS_ITER_NEW
 	PdfDocument *pdf_document = PDF_DOCUMENT (document);
 	PopplerLayersIter *iter;
 
@@ -2328,12 +2555,8 @@ pdf_document_layers_has_layers (EvDocumentLayers *document)
 	poppler_layers_iter_free (iter);
 
 	return TRUE;
-#else
-	return FALSE;
-#endif /* HAVE_POPPLER_LAYERS_ITER_NEW */
 }
 
-#ifdef HAVE_POPPLER_LAYERS_ITER_NEW
 static void
 build_layers_tree (PdfDocument       *pdf_document,
 		   GtkTreeModel      *model,
@@ -2389,13 +2612,11 @@ build_layers_tree (PdfDocument       *pdf_document,
 		poppler_layers_iter_free (child);
 	} while (poppler_layers_iter_next (iter));
 }
-#endif /* HAVE_POPPLER_LAYERS_ITER_NEW */
 
 static GtkTreeModel *
 pdf_document_layers_get_layers (EvDocumentLayers *document)
 {
 	GtkTreeModel *model = NULL;
-#ifdef HAVE_POPPLER_LAYERS_ITER_NEW
 	PdfDocument *pdf_document = PDF_DOCUMENT (document);
 	PopplerLayersIter *iter;
 
@@ -2411,8 +2632,6 @@ pdf_document_layers_get_layers (EvDocumentLayers *document)
 		build_layers_tree (pdf_document, model, NULL, iter);
 		poppler_layers_iter_free (iter);
 	}
-	
-#endif
 	return model;
 }
 
@@ -2420,42 +2639,30 @@ static void
 pdf_document_layers_show_layer (EvDocumentLayers *document,
 				EvLayer          *layer)
 {
-#ifdef HAVE_POPPLER_LAYERS_ITER_NEW
 	PdfDocument *pdf_document = PDF_DOCUMENT (document);
 	guint        layer_id = ev_layer_get_id (layer);
 
 	poppler_layer_show (POPPLER_LAYER (g_list_nth_data (pdf_document->layers, layer_id)));
-#else
-	return;
-#endif /* HAVE_POPPLER_LAYERS_ITER_NEW */
 }
 
 static void
 pdf_document_layers_hide_layer (EvDocumentLayers *document,
 				EvLayer          *layer)
 {
-#ifdef HAVE_POPPLER_LAYERS_ITER_NEW
 	PdfDocument *pdf_document = PDF_DOCUMENT (document);
 	guint        layer_id = ev_layer_get_id (layer);
 
 	poppler_layer_hide (POPPLER_LAYER (g_list_nth_data (pdf_document->layers, layer_id)));
-#else
-	return;
-#endif /* HAVE_POPPLER_LAYERS_ITER_NEW */
 }
 
 static gboolean
 pdf_document_layers_layer_is_visible (EvDocumentLayers *document,
 				      EvLayer          *layer)
 {
-#ifdef HAVE_POPPLER_LAYERS_ITER_NEW
 	PdfDocument *pdf_document = PDF_DOCUMENT (document);
 	guint        layer_id = ev_layer_get_id (layer);
 
 	return poppler_layer_is_visible (POPPLER_LAYER (g_list_nth_data (pdf_document->layers, layer_id)));
-#else
-	return FALSE;
-#endif /* HAVE_POPPLER_LAYERS_ITER_NEW */
 }
 
 static void
