@@ -19,7 +19,7 @@ ev_document_error_get_type (void)
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
-       g_enum_register_static (/* g_intern_static_string */ ("EvDocumentError"), values);
+       g_enum_register_static (g_intern_static_string ("EvDocumentError"), values);
       
     g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
   }
@@ -45,7 +45,7 @@ ev_document_layout_get_type (void)
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
-       g_enum_register_static (/* g_intern_static_string */ ("EvDocumentLayout"), values);
+       g_enum_register_static (g_intern_static_string ("EvDocumentLayout"), values);
       
     g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
   }
@@ -69,7 +69,7 @@ ev_document_mode_get_type (void)
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
-       g_enum_register_static (/* g_intern_static_string */ ("EvDocumentMode"), values);
+       g_enum_register_static (g_intern_static_string ("EvDocumentMode"), values);
       
     g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
   }
@@ -94,7 +94,7 @@ ev_document_ui_hints_get_type (void)
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
-       g_flags_register_static (/* g_intern_static_string */ ("EvDocumentUIHints"), values);
+       g_flags_register_static (g_intern_static_string ("EvDocumentUIHints"), values);
       
     g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
   }
@@ -117,7 +117,7 @@ ev_document_permissions_get_type (void)
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
-       g_flags_register_static (/* g_intern_static_string */ ("EvDocumentPermissions"), values);
+       g_flags_register_static (g_intern_static_string ("EvDocumentPermissions"), values);
       
     g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
   }
@@ -152,7 +152,7 @@ ev_document_info_fields_get_type (void)
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
-       g_flags_register_static (/* g_intern_static_string */ ("EvDocumentInfoFields"), values);
+       g_flags_register_static (g_intern_static_string ("EvDocumentInfoFields"), values);
       
     g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
   }
@@ -175,7 +175,7 @@ ev_file_exporter_format_get_type (void)
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
-       g_enum_register_static (/* g_intern_static_string */ ("EvFileExporterFormat"), values);
+       g_enum_register_static (g_intern_static_string ("EvFileExporterFormat"), values);
       
     g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
   }
@@ -202,7 +202,7 @@ ev_file_exporter_capabilities_get_type (void)
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
-       g_flags_register_static (/* g_intern_static_string */ ("EvFileExporterCapabilities"), values);
+       g_flags_register_static (g_intern_static_string ("EvFileExporterCapabilities"), values);
       
     g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
   }
@@ -225,7 +225,7 @@ ev_compression_type_get_type (void)
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
-       g_enum_register_static (/* g_intern_static_string */ ("EvCompressionType"), values);
+       g_enum_register_static (g_intern_static_string ("EvCompressionType"), values);
       
     g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
   }
@@ -248,7 +248,7 @@ ev_form_field_text_type_get_type (void)
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
-       g_enum_register_static (/* g_intern_static_string */ ("EvFormFieldTextType"), values);
+       g_enum_register_static (g_intern_static_string ("EvFormFieldTextType"), values);
       
     g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
   }
@@ -269,7 +269,7 @@ ev_form_field_button_type_get_type (void)
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
-       g_enum_register_static (/* g_intern_static_string */ ("EvFormFieldButtonType"), values);
+       g_enum_register_static (g_intern_static_string ("EvFormFieldButtonType"), values);
       
     g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
   }
@@ -289,7 +289,7 @@ ev_form_field_choice_type_get_type (void)
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
-       g_enum_register_static (/* g_intern_static_string */ ("EvFormFieldChoiceType"), values);
+       g_enum_register_static (g_intern_static_string ("EvFormFieldChoiceType"), values);
       
     g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
   }
@@ -314,7 +314,7 @@ ev_link_action_type_get_type (void)
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
-       g_enum_register_static (/* g_intern_static_string */ ("EvLinkActionType"), values);
+       g_enum_register_static (g_intern_static_string ("EvLinkActionType"), values);
       
     g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
   }
@@ -343,7 +343,7 @@ ev_link_dest_type_get_type (void)
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
-       g_enum_register_static (/* g_intern_static_string */ ("EvLinkDestType"), values);
+       g_enum_register_static (g_intern_static_string ("EvLinkDestType"), values);
       
     g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
   }
@@ -366,7 +366,7 @@ ev_selection_style_get_type (void)
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
-       g_enum_register_static (/* g_intern_static_string */ ("EvSelectionStyle"), values);
+       g_enum_register_static (g_intern_static_string ("EvSelectionStyle"), values);
       
     g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
   }
@@ -398,7 +398,7 @@ ev_transition_effect_type_get_type (void)
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
-       g_enum_register_static (/* g_intern_static_string */ ("EvTransitionEffectType"), values);
+       g_enum_register_static (g_intern_static_string ("EvTransitionEffectType"), values);
       
     g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
   }
@@ -418,7 +418,7 @@ ev_transition_effect_alignment_get_type (void)
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
-       g_enum_register_static (/* g_intern_static_string */ ("EvTransitionEffectAlignment"), values);
+       g_enum_register_static (g_intern_static_string ("EvTransitionEffectAlignment"), values);
       
     g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
   }
@@ -438,7 +438,7 @@ ev_transition_effect_direction_get_type (void)
       { 0, NULL, NULL }
     };
     GType g_define_type_id = \
-       g_enum_register_static (/* g_intern_static_string */ ("EvTransitionEffectDirection"), values);
+       g_enum_register_static (g_intern_static_string ("EvTransitionEffectDirection"), values);
       
     g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
   }
