@@ -69,8 +69,6 @@ void              ev_application_open_uri_at_dest    (EvApplication   *applicati
 						      EvLinkDest      *dest,
 						      EvWindowRunMode  mode,
 						      const gchar     *search_string,
-						      gboolean         unlink_temp_file,
-						      const gchar     *print_settings, 
 						      guint32          timestamp);
 void	          ev_application_open_uri_list       (EvApplication   *application,
 		  			              GSList          *uri_list,
@@ -89,6 +87,10 @@ void		  ev_application_screensaver_disable (EvApplication   *application);
 GtkPrintSettings *ev_application_get_print_settings  (EvApplication   *application);
 void              ev_application_set_print_settings  (EvApplication   *application,
 						      GtkPrintSettings *settings);
+GtkPageSetup     *ev_application_get_page_setup      (EvApplication   *application);
+void              ev_application_set_page_setup      (EvApplication   *application,
+						      GtkPageSetup    *page_setup);
+const gchar      *ev_application_get_dot_dir         (EvApplication   *application);
 
 G_END_DECLS
 
